<?php

namespace Litecms\Buslists\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Buslists\Models\Buslists;

class BuslistsPolicy
{

    /**
     * Determine if the given user can view the buslists.
     *
     * @param UserPolicy $user
     * @param Buslists $buslists
     *
     * @return bool
     */
    public function view(UserPolicy $user, Buslists $buslists)
    {
        if ($user->canDo('buslists.buslists.view') && $user->isAdmin()) {
            return true;
        }

        return $buslists->user_id == user_id() && $buslists->user_type == user_type();
    }

    /**
     * Determine if the given user can create a buslists.
     *
     * @param UserPolicy $user
     * @param Buslists $buslists
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('buslists.buslists.create');
    }

    /**
     * Determine if the given user can update the given buslists.
     *
     * @param UserPolicy $user
     * @param Buslists $buslists
     *
     * @return bool
     */
    public function update(UserPolicy $user, Buslists $buslists)
    {
        if ($user->canDo('buslists.buslists.edit') && $user->isAdmin()) {
            return true;
        }

        return $buslists->user_id == user_id() && $buslists->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given buslists.
     *
     * @param UserPolicy $user
     * @param Buslists $buslists
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Buslists $buslists)
    {
        return $buslists->user_id == user_id() && $buslists->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given buslists.
     *
     * @param UserPolicy $user
     * @param Buslists $buslists
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Buslists $buslists)
    {
        if ($user->canDo('buslists.buslists.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given buslists.
     *
     * @param UserPolicy $user
     * @param Buslists $buslists
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Buslists $buslists)
    {
        if ($user->canDo('buslists.buslists.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
