<?php

namespace Litecms\Buslist\Providers;

use Illuminate\Support\ServiceProvider;

class BuslistServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'buslist');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'buslist');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.buslist', function ($app) {
            return $this->app->make('Litecms\Buslist\Buslist');
        });

                // Bind Buslists to repository
        $this->app->bind(
            'Litecms\Buslist\Interfaces\BuslistsRepositoryInterface',
            \Litecms\Buslist\Repositories\Eloquent\BuslistsRepository::class
        );

        $this->app->register(\Litecms\Buslist\Providers\AuthServiceProvider::class);
                $this->app->register(\Litecms\Buslist\Providers\EventServiceProvider::class);
        
        $this->app->register(\Litecms\Buslist\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.buslist'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/buslist.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/buslist')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/buslist')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
